#
# spec file
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define panel_version 4.16.0
%define plugin sensors
%bcond_with git
Name:           xfce4-%{plugin}-plugin
Version:        1.4.4
Release:        1.6
Summary:        Hardware Sensor Plugin for the Xfce Panel
License:        GPL-2.0-or-later
Group:          System/GUI/XFCE
URL:            https://docs.xfce.org/panel-plugins/xfce4-sensors-plugin
Source0:        https://archive.xfce.org/src/panel-plugins/%{name}/1.4/%{name}-%{version}.tar.bz2
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  intltool
BuildRequires:  libsensors4-devel
BuildRequires:  pkgconfig
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(glib-2.0) >= 2.50
BuildRequires:  pkgconfig(gthread-2.0)
BuildRequires:  pkgconfig(gtk+-3.0) >= 3.20
BuildRequires:  pkgconfig(libnotify)
BuildRequires:  pkgconfig(libxfce4panel-2.0) >= %{panel_version}
BuildRequires:  pkgconfig(libxfce4ui-2) >= %{panel_version}
BuildRequires:  pkgconfig(libxfce4util-1.0) >= 4.17.2
%if %{with git}
BuildRequires:  xfce4-dev-tools
%endif
Requires:       xfce4-panel >= %{panel_version}
Recommends:     %{name}-lang = %{version}
Recommends:     hddtemp
Recommends:     netcat-openbsd
# package was renamed in 2019 after Leap 15.1
Provides:       xfce4-panel-plugin-%{plugin} = %{version}-%{release}
Obsoletes:      xfce4-panel-plugin-%{plugin} < %{version}-%{release}
Obsoletes:      xfce4-panel-plugin-%{plugin}-debuginfo

%description
The Sensors plugin and standalone application allow to monitor various hardware
sensors supported by libsensors.

%package devel
Summary:        Development Files for %{name}
Group:          Development/Libraries/C and C++
Requires:       %{name} = %{version}
Requires:       xfce4-panel >= %{panel_version}
# package was renamed in 2019 after Leap 15.1
Obsoletes:      xfce4-panel-plugin-%{plugin}-devel < %{version}-%{release}
Provides:       xfce4-panel-plugin-%{plugin}-devel = %{version}-%{release}

%description devel
This package contains the development files needed to develop applications
based on libxfce4sensors.

%package lang
Summary:        Translations for package %{name}
Group:          System/Localization
Requires:       %{name} = %{version}
Supplements:    %{name}
Provides:       %{name}-lang-all = %{version}
# package was renamed in 2019 after Leap 15.1
Obsoletes:      xfce4-panel-plugin-%{plugin}-lang < %{version}-%{release}
Provides:       xfce4-panel-plugin-%{plugin}-lang = %{version}-%{release}
BuildArch:      noarch

%description lang
Provides translations for the "%{name}" package.

%prep
%autosetup -p1

%build
# gcc10 workaround
export CFLAGS="%{optflags} -fcommon"

# --enable-netcat actually enables "hddtemp via netcat"
%if %{with git}
NOCONFIGURE=1 ./autogen.sh
%configure \
    --enable-maintainer-mode \
    --disable-static \
    --enable-libsensors=yes \
    --enable-pathchecks=no \
    --enable-hddtemp \
    --with-pathhddtemp=/usr/sbin/hddtemp \
    --enable-netcat \
    --with-pathnetcat=/usr/bin/netcat \
    --enable-sysfsacpi
%else
%configure \
    --disable-static \
    --enable-libsensors=yes \
    --enable-pathchecks=no \
    --enable-hddtemp \
    --with-pathhddtemp=/usr/sbin/hddtemp \
    --enable-netcat \
    --with-pathnetcat=/usr/bin/netcat \
    --enable-sysfsacpi
%endif
%make_build

%install
%make_install

rm -rf %{buildroot}%{_libdir}/xfce4/modules/libxfce4sensors.la

%suse_update_desktop_file -r xfce4-sensors X-XFCE System Monitor

rm -rf %{buildroot}%{_datadir}/locale/{ast,kk,tl_PH,ur_PK}

rm -f %{buildroot}%{_libdir}/xfce4/panel/plugins/libxfce4-sensors-plugin.la

%find_lang %{name} %{name}.lang %{?no_lang_C}

%fdupes %{buildroot}%{_datadir}

%files
%doc AUTHORS NEWS NOTES README TODO
%license LICENSE
%{_bindir}/xfce4-sensors
%{_libdir}/xfce4/panel/plugins/libxfce4-sensors-plugin.so
%{_datadir}/icons/hicolor/*/apps/xfce-sensors.*
%{_datadir}/applications/xfce4-sensors.desktop
%{_datadir}/xfce4/panel/plugins/xfce4-sensors-plugin.desktop
%{_datadir}/xfce4/panel/plugins/xfce4-sensors-plugin.css
%dir %{_libdir}/xfce4
%dir %{_libdir}/xfce4/modules
%{_libdir}/xfce4/modules/libxfce4sensors.so.*
%doc %{_mandir}/man1/xfce4-sensors.1*

%files devel
%{_libdir}/pkgconfig/*.pc
%{_libdir}/xfce4/modules/libxfce4sensors.so

%files lang -f %{name}.lang

%changelog
* Fri Dec 23 2022 Manfred Hollstein <manfred.h@gmx.net>
- Update to version 1.4.4
  * Bump build requirements for Xfce 4.18.0
  * Remove code obsoleted by libxfce4util-4.17.2
  * Fix GLib warnings occurring with newer xfce4-dev-tools
  * Update pkgconfig
  * Fix intltool lock file problem during make distcheck
  * Update COPYING
  * Translation Updates
- Remove _service file
- Remove libxfce4ui.patch, it is no longer needed
* Wed Feb  2 2022 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to version 1.4.3
  * Fix translations not showing in the GUI
  * Use locale-independent floats in configuration files
  * Translation Updates
* Sun Nov 21 2021 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to version 1.4.2
  * Migrate Source from C to C++
  * Prevent overlap of tachometer titles
  * Improved standalone app layout
  * Fix crash in hddtemp codepath with a SATA SSD drive
  * Increase default temperature ranges of HDDs and NVIDIA GPUs by 10℃
  * Remove default values from RC configuration files
  * Suppress title after the user adds the 1st sensor
  * Remove hard-coded limits restricting the maximum number of sensors
  * Test all possible build configurations using brute-force search
  * Use xfce4::connect instead of the less safe g_signal_connect
  * Enable lm_sensors in GitLab distcheck
  * Fix memory leaks
  * Translation Updates
* Sat Jul 31 2021 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to version 1.4.1
  * Update hddtemp netcat support
  * Check for libsensors if it is explicitly enabled
  * Use a drawing area to display sensor data in text UI style
  * Fix a use-after-free error when closing the main window
  * Increase main window size from 400 to 800 pixels
  * Fix a use-after-free error when disabling a tachometer
  * Fix preliminary config memory leak
  * Improved handling of denormal floating-point values
  * Update automatic coloring of progress bars
  * Update and sort the list of authors
  * Corrections to the number of rows when displaying sensor data as text
  * Remove support for lm-sensors 2.x (API < 0x400)
  * Center tachometers vertically
  * Layout sensors when cover-all-rows is toggled
  * Fix invalid "size-changed" callback function declaration
  * Avoid interference of tachometer allocations with GtkBox child allocs
  * configure: Remove nano version and update init arguments
  * configure: Bump required glib to 2.50
  * configure: Bump required Xfce libs to 4.14
  * configure: Remove checks covered by C99
  * configure: Remove UNIX variants check
  * Ellipsize labels only when needed
  * Remove support for libnotify 0.4
  * Enable automatic switching of colors based on light or dark UI theme
  * Move text inside the tachometer
  * Remove unused options.dialog files
  * Use capital letters when spelling NVIDIA
  * Code cleanup: Shorten all variable names to speedup readability
  * Use a single bit to store boolean values
  * Prevent memset2() from compiling because of a double-increment bug
  * Fix fgets() compiler warning
  * Code cleanup: Remove all TRACE() lines
  * Fix invalid order of widgets after changing panel orientation
  * Fix accesses to destroyed widgets when changing the panel orientation
  * Increase icon size in about dialog from 32 to 48 pixels
  * Update copyright year in about dialog
  * Fix invalid state flag
  * Include X11 headers before NVCtrl headers
  * Translation Updates
* Tue Jan 12 2021 Maurizio Galli <maurizio.galli@gmail.com>
- Added libxfce4ui.patch to  require libxfce4ui-2 for devel package
  instead of obsolete libxfce4ui-1
* Mon Dec 28 2020 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to version 1.3.95
  * make compatible with Xfce 4.16
  * code cleanup
  * translation updates
* Mon Jun  8 2020 Marcel Kuehlhorn <tux93@opensuse.org>
- add -fcommon to CFLAGS as temporary workaround for gcc10 default
  changes
* Fri Aug 16 2019 Maurizio Galli <maurizio.galli@gmail.com>
- Fixed sources in spec file
* Wed Jul 17 2019 Maurizio Galli <maurizio.galli@gmail.com>
- Package renamed to follow upstream name xfce4-foo-plugin
- Use lang subpackage for manual edits instead of %%lang_package macro
- Cleaned up spec file
- Added bcond for git master builds
- Only add NEWS and omit Changelog
* Fri May 25 2018 seife+obs@b1-systems.com
- update to version 1.3.0
  * no upstream changelog :-(
  * ported to gtk3
  * translation updates
- remove obsolete xfce4-sensors-plugin-force-hddtemp-netcat.patch
- use %%license for LICENSE, drop similar COPYING file
* Wed Mar  1 2017 seife+obs@b1-systems.com
- enable hddtemp (boo#763293)
  add xfce4-sensors-plugin-force-hddtemp-netcat.patch
* Fri Feb 27 2015 gber@opensuse.org
- update to version 1.2.6
  - support for thermal_zoneX folders in sysfs
  - inhibit various plugin crashes
  - tooltip automatically deactivated for tacho view so that plugin
    doesn't crash then (can be reactivated in settings dialog from
    panel settings -> objects -> sensors plugin -> properties)
* Wed May 16 2012 gber@opensuse.org
- update to version 1.2.5
  - fix German translation
  - fix build with --enable-hddtemp=yes
* Mon May 14 2012 gber@opensuse.org
- update to version 1.2.4
  - fix some memory issues
  - stabilize support for hddtemp
  - improve battery reading via ACPI and sysfs
  - translation updates
* Fri Apr 20 2012 gber@opensuse.org
- added documentation files
* Tue Apr 17 2012 gber@opensuse.org
- corrected source URL
* Wed Apr  4 2012 gber@opensuse.org
- specfile cleanup
- split off -lang subpackage
* Mon Sep 19 2011 gber@opensuse.org
- update to version 1.2.3
  - Build issues with gcc 4.6
  - autotool stuff
  - nvidis sensor support
  - libnotify support for version 0.7
  - safer saving of font for tachometers
  - added missing files to repository
  - make distcheck works again
  - applied, verified, corrected patches by various people
  - hddtemp and netcat should work with the port-version now
- dropped obsolete
  xfce4-panel-plugin-sensors-1.0.0-fix-build-with-4.7.patch,
  xfce4-panel-plugin-sensors-1.0.0-fix-ldflags.patch,
  xfce4-panel-plugin-sensors-1.0.0-fix-libnotify-0.7.patch,
  xfce4-panel-plugin-sensors-1.0.0-fix-memory-leaks.patch,
  xfce4-panel-plugin-sensors-1.0.0-fix-uninitialized-memory.patch
* Fri Sep 16 2011 andrea.turrini@gmail.com
- fixed typos in xfce4-panel-plugin-sensors.spec
* Wed May  4 2011 gber@opensuse.org
- added xfce4-panel-plugin-sensors-1.0.0-fix-libnotify-0.7.patch
  in order to adapt to libnotify 0.7.0 API changes
* Mon May  2 2011 gber@opensuse.org
- added xfce4-panel-plugin-sensors-1.0.0-fix-ldflags.patch which
  fixes LDFLAGS for use with gcc 4.6
* Wed Mar  9 2011 gber@opensuse.org
- new package (split off from xfce4-panel-plugins)
